==> ad_klein_flutter_sdk-1.0.0.tar.gz: android/src/main/java/com/iusmob/ad_klein_flutter_sdk/SplashAdActivity.java <==
package com.iusmob.ad_klein_flutter_sdk;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.core.content.ContextCompat;

import com.iusmob.adklein.ad.AdKleinSDK;
import com.iusmob.adklein.ad.AdKleinError;
import com.iusmob.adklein.ad.AdKleinSplashAd;
import com.iusmob.adklein.ad.AdKleinSplashAdListener;

public class SplashAdActivity extends Activity {

    private static AdInstanceManager adInstanceManager;
    private static final String AD_ID_KEY = "AD_ID_KEY";
    private static final String AD_POS_ID_KEY = "AD_POS_ID_KEY";

    private int adId;
    private AdKleinSplashAd kleinSplash;
    private FrameLayout adContainer;
    private String adPosId;

    public static void startActivity(Context context, AdInstanceManager manager, int adId, String adPosId) {
        adInstanceManager = manager;
        Intent intent = new Intent(context, SplashAdActivity.class);
        intent.putExtra(AD_ID_KEY, adId);
        intent.putExtra(AD_POS_ID_KEY, adPosId);
        context.startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Intent intent = getIntent();
        if (intent != null) {
            adId = intent.getIntExtra(AD_ID_KEY, -1);
            adPosId = intent.getStringExtra(AD_POS_ID_KEY);
        }
        setContentView(R.layout.activity_splash_ad);
        adContainer = findViewById(R.id.ad_container);
        loadSplashAd();
    }

    private void loadSplashAd() {
        // ，创建开屏广告实例第一个参数可以是Activity或Fragment，第二个参数是广告容器（请保证容器不会拦截点击、触摸等事件）
        kleinSplash = new AdKleinSplashAd(this, adContainer,
                adPosId, new AdKleinSplashAdListener() {
            @Override
            public void onAdClosed() {
                adInstanceManager.onAdClose(adInstanceManager.adForId(adId));
                jumpMain();
            }

            @Override
            public void onAdSkip() {
            }

            @Override
            public void onAdTick(int millisUntilFinished) {
            }

            @Override
            public void onError(AdKleinError adKleinError) {
                adInstanceManager.onAdFailed(adInstanceManager.adForId(adId), adKleinError);
                jumpMain();
            }

            @Override
            public void onAdLoaded() {
                adInstanceManager.onAdReceive(adInstanceManager.adForId(adId));
                kleinSplash.show();
            }

            @Override
            public void onAdShow() {
                adInstanceManager.onAdExpose(adInstanceManager.adForId(adId));
            }

            @Override
            public void onAdClicked() {
                adInstanceManager.onAdClick(adInstanceManager.adForId(adId));
            }
        });
        kleinSplash.load();
    }

    @Override
    public void onBackPressed() {
        // 取消返回事件，增加开屏曝光率
    }

    /**
     * 跳转到主界面
     */
    private void jumpMain() {
        finish();
    }

}

==> ad_klein_flutter_sdk-1.2.0.tar.gz: android/src/main/java/com/iusmob/ad_klein_flutter_sdk/SplashAdActivity.java <==
package com.iusmob.ad_klein_flutter_sdk;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.core.content.ContextCompat;

import com.iusmob.adklein.ad.AdKleinSDK;
import com.iusmob.adklein.ad.AdKleinError;
import com.iusmob.adklein.ad.AdKleinSplashAd;
import com.iusmob.adklein.ad.AdKleinSplashAdListener;

public class SplashAdActivity extends Activity {

    private static AdInstanceManager adInstanceManager;
    private static final String AD_ID_KEY = "AD_ID_KEY";
    private static final String AD_POS_ID_KEY = "AD_POS_ID_KEY";

    private int adId;
    private AdKleinSplashAd kleinSplash;
    private FrameLayout adContainer;
    private String adPosId;

    public static void startActivity(Context context, AdInstanceManager manager, int adId,
                                     String adPosId) {
        adInstanceManager = manager;
        Intent intent = new Intent(context, SplashAdActivity.class);
        intent.putExtra(AD_ID_KEY, adId);
        intent.putExtra(AD_POS_ID_KEY, adPosId);
        context.startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().getDecorView().setSystemUiVisibility(View.INVISIBLE);
        Intent intent = getIntent();
        if (intent != null) {
            adId = intent.getIntExtra(AD_ID_KEY, -1);
            adPosId = intent.getStringExtra(AD_POS_ID_KEY);
        }
        setContentView(R.layout.activity_splash_ad);
        adContainer = findViewById(R.id.ad_container);
        loadSplashAd();
    }

    private void loadSplashAd() {
        // ，创建开屏广告实例第一个参数可以是Activity或Fragment，第二个参数是广告容器（请保证容器不会拦截点击、触摸等事件）
        kleinSplash = new AdKleinSplashAd(this, adContainer,
                adPosId, new AdKleinSplashAdListener() {
            @Override
            public void onAdClosed() {
                adInstanceManager.onAdClose(adInstanceManager.adForId(adId));
                jumpMain();
            }

            @Override
            public void onAdSkip() {
            }

            @Override
            public void onAdTick(int millisUntilFinished) {
            }

            @Override
            public void onError(AdKleinError adKleinError) {
                adInstanceManager.onAdFailed(adInstanceManager.adForId(adId), adKleinError);
                jumpMain();
            }

            @Override
            public void onAdLoaded() {
                adInstanceManager.onAdReceive(adInstanceManager.adForId(adId));
                kleinSplash.show();
            }

            @Override
            public void onAdShow() {
                adInstanceManager.onAdExpose(adInstanceManager.adForId(adId));
            }

            @Override
            public void onAdClicked() {
                adInstanceManager.onAdClick(adInstanceManager.adForId(adId));
            }
        }, 5000);
        kleinSplash.load();
    }

    @Override
    public void onBackPressed() {
        // 取消返回事件，增加开屏曝光率
    }

    /**
     * 跳转到主界面
     */
    private void jumpMain() {
        finish();
    }

}
